@@ -1,27 +1,124 @@
+#ifndef __XFFM_CONSTANTS_H__
+#define __XFFM_CONSTANTS_H__
+#include "errors.h"
+#include "types.h"
+#include <gmodule.h>
 
-#ifndef __CONSTANTS_H__
-#define __CONSTANTS_H__
+#include <libxfce4util/libxfce4util.h>
+#define CUT_BUFFER 0
 
-#define CURRENT_RUN_HISTORY "xffm%cxffm.runlist.2.dbh"
-#define CURRENT_GO_HISTORY "xffm%cxffm.golist.2.dbh"
-#define CURRENT_WORKDIR_HISTORY "xffm%cxffm.workdir.2.dbh"
+/*#ifdef HAVE_LIBXFCE4UTIL
+#include <libxfce4util/libxfce4util.h>
+#else
+#define DBG(...)   G_STMT_START{ (void)0; }G_STMT_END
+#define TRACE(...) G_STMT_START{ (void)0; }G_STMT_END
+#endif*/
 
-/*#define D(x) {printf(x);fflush(NULL);}*/
- #define D(x)
-#define ACTIVATE_BOOK	0X01
-#define ACTIVATE_LOCAL	0X02
-#define ACTIVATE_SMB	0X04
-#define ACTIVATE_APPS	0X08
-#define ACTIVATE_TRASH	0X10
-#define ACTIVATE_FSTAB	0X20
-#define ACTIVATE_FIND	0X40
+/*XXX these should be removed from sources: */
+#undef USE_FILTER_BAR
+#define USE_FILTER_BAR 1
+#undef USE_EXTENDPREFS
+#define USE_EXTENDPREFS 1
 
-#define __VY_FN__(y) ((strlen(y)<2 || !strchr(y,'/'))?abreviate(y):abreviate(strrchr(y,'/')+1) )
-#define __VX_FN__(y) ((strlen(y)<2 || !strchr(y,'/'))? y:strrchr(y,'/')+1)
-#define __AB_FN__(x) ((1)?__VY_FN__(x->path):__VX_FN__(x->path))
-#define FILENAME(x) (x?( (x->path && strlen(x->path))?__AB_FN__(x):" " ):"null entry!")
+#define BLACK_HOLE    g_warning("BLACK HOLE..."); while (gtk_events_pending())gtk_main_iteration(); while (1);
+
+
+/*****  mime ****/
+
+#define FREEDESKTOP_MIME_FILE PACKAGE_DATA_DIR,"xffm","freedesktop.org.xml"
+#define MAGIC_MIME_FILE PACKAGE_DATA_DIR,"xffm","types.xml"
+#define APPLICATION_MIME_FILE PACKAGE_DATA_DIR,"xffm","applications-module.xml"
+
+
+/***** end mime ****/
+
+#define SMALL GTK_ICON_SIZE_BUTTON
+#define MEDIUM GTK_ICON_SIZE_LARGE_TOOLBAR
+#define REAL_BIG GTK_ICON_SIZE_DIALOG
+#define BIG GTK_ICON_SIZE_DND
+
+#define GETWD (g_get_home_dir()?g_get_home_dir():g_get_tmp_dir())
+						 
+#define MCS_PLUGIN_FILE "xfce4","mcs_settings","xffm.xml"
+
+/* histories */
+
+/* old place */
+
+#define OLD_CACHE "xfce4","xffm"				
+#define NEW_CACHE "xffm"
+#define OLD_CONFIG "xfce4","xffm"
+#define NEW_CONFIG "xffm"
+#define OLD_MODULES "xfce4","xfce4-modules"
+#define NEW_MODULES "xffm","modules"
+						
+						 			    	
+/* new_place */
+#define LOCAL_APPLICATION_MIME_FILE "xffm","modules","applications.xml"
+#define RUN_FLAG_FILE "xffm","modules","runflag.2.dbh"
+#define RUN_DBH_FILE "xffm","modules","runlist.2.dbh"
+						 
+#define OPEN_FILE "xffm","histories","xffm.open.2.dbh"
+#define CURRENT_TRASHBIN "xffm","histories","xffm.trash.2.dbh"
+#define GOTO_DBH_FILE "xffm","histories","xffm.golist.4.dbh"
+#define WORKDIR_DBH_FILE "xffm","histories","xffm.workdir.4.dbh"
+#define FILTER_DBH_FILE "xffm","histories","xffm.flist.4.dbh"
+#define FIND_DBH_FILE "xffm","histories","xffm.fflist.2.dbh"
+#define FIND_PATHS_DBH_FILE "xffm","histories","xffm.fplist.4.dbh"
+#define FIND_GREP_DBH_FILE "xffm","histories","xffm.fglist.2.dbh"
+#define GRIDVIEW_GEOMETRY_DBH_FILE "xffm","histories","xfce4-fm.geometry.3.dbh"
+#define GRIDVIEW_PREFERENCES_DBH_FILE "xffm","histories","xfce4-fm.preferences.2.dbh"
+#define BOOKMARK_DIR "xffm","books"
+
+#define XFFM_RC_FILE "xffm"
+
+#define LOG_DIR g_get_home_dir(),".cache","xffm"
+#define LOG_FILE LOG_DIR,"xffm_error.log"
+
+/* custom assert_not_reached() for xffm */
+#ifdef __GNUC__
+#define assert_not_reached()		G_STMT_START{						\
+   {												\
+	char *logdir=g_build_filename(LOG_DIR,NULL);						\
+	char *logfile=g_build_filename(LOG_FILE,NULL);						\
+	FILE *f=fopen(logfile,"a");								\
+        fprintf(stderr, "xffm: logfile = %s\n",logfile);					\
+        fprintf(stderr, "xffm: dumping core at= %s\n",logdir);					\
+	chdir(logdir);	g_free(logdir); g_free(logfile);					\
+	fprintf(f,"%s%s Core dump --> file %s: line %d (%s): should not be reached\n",		\
+			tod(),(g_get_prgname())?g_get_prgname():"?",				\
+			__FILE__,								\
+			__LINE__,								\
+			__PRETTY_FUNCTION__);							\
+	fclose(f);										\
+	abort();										\
+   };					}G_STMT_END
+#else /* !__GNUC__ */
+
+#define assert_not_reached()		G_STMT_START{						\
+   {												\
+	char *logdir=g_build_filename(LOG_DIR,NULL);						\
+	char *logfile=g_build_filename(LOG_FILE,NULL);						\
+	FILE *f=fopen(logfile,"a");								\
+        fprintf(stderr, "xffm: logfile = %s\n",logfile);					\
+        fprintf(stderr, "xffm: dumping core at= %s\n",logdir);					\
+	chdir(logdir);	g_free(logdir); g_free(logfile);					\
+	fprintf(f,"%s%s Core dump --> file %s: line %d (not GNUC): should not be reached\n",	\
+			tod(),(g_get_prgname())?g_get_prgname():"?",				\
+			__FILE__,								\
+			__LINE__);								\
+	fclose(f);										\
+	abort();		    								\
+   };					}G_STMT_END
+#endif /* __GNUC__ */
+
+#define FILENAME(x) (x?(xffm_get_basename(x->path)):"")
 
 #define NO_ICON -1
+#define IS_MODULE_TYPE(x) (IS_ROOT_TYPE(x) && !IS_LOCAL_TYPE(x))
+
+#define COMM_IGNORE_RELEASE   0x01
+    
 
 /* subtype: */
 
@@ -34,6 +131,7 @@
 #define __NFS_TYPE	0x10
 #define __PROC_TYPE	0x20
 #define __CDFS_TYPE	0x40
+#define __SMB_TYPE	0x80
 
 #define __NETDIR	0x100
 #define __NETHIDDEN	0x200
@@ -41,6 +139,7 @@
 #define __NETFILE	0x800
 
 #define __SAMBA_SERVER	0x1000
+#define __TOP_BOOKMARK	0x2000
 
 #define  __IN_TERM	0x4000000
 #define  __CUSTOM_ICON	0x8000000
@@ -52,6 +151,7 @@
 #define TR_COPY		0x01
 #define TR_MOVE		0x02
 #define TR_LINK		0x04
+#define TR_DUPLICATE	0x08
 
 #define GOTO_WAIT 	0x01
 #define CALLBACK_WAIT	0x02
@@ -72,23 +172,22 @@
 #define __XF_DIR       	0x04
 #define __XF_BLK       	0x05
 #define __XF_REG       	0x06
-#define __XF_LNK       	0x07
+/* link flag should not be exclusive. duh... */
+/* #define __XF_LNK       	0x07 */
 #define __XF_SOCK      	0x08
 #define __XF_WHT       	0x09
 #define __XF_FND	0x0a
-#define __XF_RPM_CHILD	0x0b
+#define __XF_NODE	0x0b
 #define __XF_TAR_CHILD	0x0c
-#define __XF_FSTAB	0x0d
+/*#define __XF_FSTAB	0x0d*/
 #define __XF_MASK	0x0f	/* no available type   */
 /* hex : */
 #define __NETWORK_TYPE	0x10
 #define __LOCAL_TYPE	0x20
 #define __FIND_TYPE	0x30
 #define __BOOKMARK_TYPE	0x40
-/*#define ___TYPE	0x50*/
-#define __TRASH_TYPE	0x60
-#define __FSTAB_TYPE	0x70
-#define __APP_TYPE	0x80
+#define __TRASH_TYPE	0x50
+#define __FSTAB_TYPE	0x60
 
 #define __TREE_MASK	0xf0	/* more TREE types available */
 /* hex .: */
@@ -97,6 +196,9 @@
 #define __EXPANDED	0x400
 #define __LOADED	0x800
 /* hex :: */
+#define __XF_LNK	0x1000
+#if 0
+/* now available... */
 #define __SORT_SIZE	0x1000
 #define __SORT_TIME	0x2000
 #define __SORT_UID	0x3000
@@ -104,8 +206,10 @@
 #define __SORT_MASK	0x7000	/* 0 more SORT types available */
 #define __TYPE_SUBSORT  0x8000
 
+#endif
 /* hex | */
-#define __SORT_DESC	0x10000
+/*#define __DEFAULT_GEOMETRY	0x10000*/
+
 #define __BROKEN_LNK	0x20000
 #define __HAS_HIDDEN	0x40000
 #define __SHOW_HIDDEN	0x80000
@@ -116,11 +220,13 @@
 #define __NOWRITE	0x400000
 #define __NOACCESS	0x800000
 
+#if 0
 /* hex |: */
 #define __SIZE_M	0x1000000	/* slightly bigger 24 pt. */
 #define __SIZE_L	0x2000000	/* even bigger 36 pt. */
 #define __SIZE_XL	0x3000000	/* even bigger (not used now) */
 #define __SIZE_MASK	0x3000000
+#endif
 
 #define  __MOUNTED	0x4000000
 #define  __INCOMPLETE	0x8000000
@@ -129,24 +235,16 @@
 #define  __SHOW_IMAGES	0x40000000 
 
 /* hex |.: */
-/*#define  __AVAILABLE	0x80000000 */
+/*#define  __SHADED	0x80000000 available...*/
 
 
 
 /******************************************************/
-
-#define IS_IMAGE(x)	(strstr(x, ".tif") || strstr(x, ".TIF") ||  \
-			 strstr(x, ".png") || strstr(x, ".PNG") || \
-			 strstr(x, ".GIF") || strstr(x, ".gif") || \
-			 strstr(x, ".JPG") || strstr(x, ".jpg") || \
-			 strstr(x, ".JPEG") || strstr(x, ".jpeg") || \
-			 strstr(x, ".XPM") || strstr(x, ".xpm") || \
-			 strstr(x, ".pm") || strstr(x, ".PM") || \
-			 strstr(x, ".bmp") || strstr(x, ".BMP")) 
+#define IS_IMAGE(x)	is_image(x)
 
 
 #define SORT_OPTIONS 		(__SORT_MASK|__SORT_DESC|__TYPE_SUBSORT)
-#define INHERIT_OPTIONS 	(__SHOW_HIDDEN|__SIZE_MASK|SORT_OPTIONS|__TREE_MASK|__SHOW_IMAGES)
+#define INHERIT_OPTIONS 	(__SHOW_HIDDEN|__TREE_MASK|__SHOW_IMAGES)
 #define INHERIT_TYPE(x,y)       x |= ((y)& INHERIT_OPTIONS)
 
 			  /*(x)==__XF_NETPRINT || 
@@ -158,6 +256,8 @@
 
 #define IS_FILE(x)	(!IS_DIR(x) && \
 		(IS_XF_REG(x) || \
+		 IS_XF_CHR(x) || \
+		 IS_XF_BLK(x) || \
 		 IS_XF_FIFO(x) || \
 		 IS_XF_LNK(x) || \
 		 IS_BROKEN_LNK(x) || \
@@ -165,6 +265,15 @@
 		 IS_XF_TAR_CHILD(x)) \
 		)
 #define IS_PATH(x) (IS_DIR(x) || IS_FILE(x))
+/*
+#define IS_NODE(x,y) 	(IS_DIR(x) || \
+		         IS_XF_NETWG(y) || \
+		         IS_XF_NETWS(y) || \
+		         IS_NETDIR(y) || \
+		         IS_XF_NETSHARE(y) \
+			)*/
+    
+#define IS_NODE(x) 	(IS_DIR(x) || IS_XF_NODE(x))
 
 
 /* hex  . */
@@ -174,16 +283,17 @@
 #define IS_XF_DIR(x)		(__XF_DIR == ((x)  & __XF_MASK))
 #define IS_XF_BLK(x)		(__XF_BLK == ((x)  & __XF_MASK))
 #define IS_XF_REG(x)		(__XF_REG == ((x)  & __XF_MASK))
-#define IS_XF_LNK(x)		(__XF_LNK == ((x)  & __XF_MASK))
+#define IS_XF_LNK(x)		(__XF_LNK & (x))
 #define IS_XF_SOCK(x)		(__XF_SOCK == ((x) & __XF_MASK))
 #define IS_XF_WHT(x)		(__XF_WHT == ((x)  & __XF_MASK))
 #define IS_XF_FND(x)		(__XF_FND == ((x)  & __XF_MASK))
-#define IS_XF_FSTAB(x)		(__XF_FSTAB == ((x)  & __XF_MASK))
+/*#define IS_XF_FSTAB(x)		(__XF_FSTAB == ((x)  & __XF_MASK))*/
 #define IS_XF_NETWG(x)		(__XF_NETWG == ((x)  & __XF_MASK))
 #define IS_XF_NETWS(x)		(__XF_NETWS == ((x)  & __XF_MASK))
 #define IS_XF_NETSHARE(x)	(__XF_NETSHARE == ((x)  & __XF_MASK))
 #define IS_XF_NETPRINT(x)	(__XF_NETPRINT == ((x)  & __XF_MASK))
 #define IS_XF_NETIPC(x)		(__XF_NETIPC == ((x)  & __XF_MASK))
+#define IS_XF_NODE(x)		(__XF_NODE == ((x)  & __XF_MASK))
 
 #define IS_XF_RPM_CHILD(x)	(__XF_RPM_CHILD == ((x)  & __XF_MASK))
 #define IS_XF_TAR_CHILD(x)	(__XF_TAR_CHILD == ((x)  & __XF_MASK))
@@ -195,18 +305,17 @@
 #define SET_XF_DIR(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_DIR)
 #define SET_XF_BLK(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_BLK)
 #define SET_XF_REG(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_REG)
-#define SET_XF_LNK(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_LNK)
+#define SET_XF_LNK(x)	((x) |= __XF_LNK)
 #define SET_XF_SOCK(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_SOCK)
 #define SET_XF_WHT(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_WHT)
 #define SET_XF_FND(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_FND)
-#define SET_XF_FSTAB(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_FSTAB)
+/*#define SET_XF_FSTAB(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_FSTAB)*/
 #define SET_XF_NETWG(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_NETWG)
 #define SET_XF_NETWS(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_NETWS)
+#define SET_XF_NODE(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_NODE)
 #define SET_XF_NETSHARE(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_NETSHARE)
 #define SET_XF_NETPRINT(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_NETPRINT)
 #define SET_XF_NETIPC(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_NETIPC)
-#define SET_XF_RPM_CHILD(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_RPM_CHILD)
-#define SET_XF_TAR_CHILD(x)	(x) = (((x)&(__XF_MASK^__MASK)) | __XF_TAR_CHILD)
 
 /* hex  : */
 #define IS_NETWORK_TYPE(x)	(((x) & __TREE_MASK) == __NETWORK_TYPE)
@@ -217,20 +326,20 @@
 #define IS_TRASH_TYPE(x)	(((x) & __TREE_MASK) == __TRASH_TYPE)
 #define IS_FSTAB_TYPE(x)	(((x) & __TREE_MASK) == __FSTAB_TYPE)
 #define IS_NFS_TYPE(x)		(((x) & __TREE_MASK) == __NFS_TYPE)
+#define IS_SMB_TYPE(x)		(((x) & __TREE_MASK) == __SMB_TYPE)
 #define IS_PROC_TYPE(x)		(((x) & __TREE_MASK) == __PROC_TYPE)
 #define IS_CDFS_TYPE(x)		(((x) & __TREE_MASK) == __CDFS_TYPE)
-#define IS_APP_TYPE(x)		(((x) & __TREE_MASK) == __APP_TYPE)
 
 #define SET_LOCAL_TYPE(x)	(x) = (((x)&(__TREE_MASK^__MASK)) | __LOCAL_TYPE)
 #define SET_NETWORK_TYPE(x)	(x) = (((x)&(__TREE_MASK^__MASK)) | __NETWORK_TYPE)
 #define SET_FIND_TYPE(x)	(x) = (((x)&(__TREE_MASK^__MASK)) | __FIND_TYPE)
-#define SET_BOOKMARK_TYPE(x)	(x) = (((x)&(__TREE_MASK^__MASK)) | __BOOK_TYPE)
+#define SET_BOOKMARK_TYPE(x)	(x) = (((x)&(__TREE_MASK^__MASK)) | __BOOKMARK_TYPE)
 #define SET_TRASH_TYPE(x)	(x) = (((x)&(__TREE_MASK^__MASK)) | __TRASH_TYPE)
 #define SET_FSTAB_TYPE(x)	(x) = (((x)&(__TREE_MASK^__MASK)) | __FSTAB_TYPE)
 #define SET_NFS_TYPE(x)		(x) = (((x)&(__TREE_MASK^__MASK)) | __NFS_TYPE)
+#define SET_SMB_TYPE(x)		(x) = (((x)&(__TREE_MASK^__MASK)) | __SMB_TYPE)
 #define SET_PROC_TYPE(x)	(x) = (((x)&(__TREE_MASK^__MASK)) | __PROC_TYPE)
 #define SET_CDFS_TYPE(x)	(x) = (((x)&(__TREE_MASK^__MASK)) | __CDFS_TYPE)
-#define SET_APP_TYPE(x)		(x) = (((x)&(__TREE_MASK^__MASK)) | __APP_TYPE)
 
 /* hex  .: */
 #define IS_NETDIR(x)		((x) & __NETDIR)
@@ -244,12 +353,14 @@
 
 
 #define IS_SAMBA_SERVER(x)	((x) & __SAMBA_SERVER)
+#define IS_TOP_BOOKMARK(x)	((x) & __TOP_BOOKMARK)
 #define IS_ROOT_TYPE(x)		((x) & __ROOT_TYPE)
 #define IS_DUMMY_TYPE(x)	((x) & __DUMMY_TYPE)
 #define IS_EXPANDED(x)		((x) & __EXPANDED)
 #define IS_LOADED(x)		((x) & __LOADED)
 
 #define SET_SAMBA_SERVER(x)	(x) |= __SAMBA_SERVER
+#define SET_TOP_BOOKMARK(x)	(x) |=  __TOP_BOOKMARK
 #define SET_ROOT_TYPE(x)	(x) |= __ROOT_TYPE
 #define SET_DUMMY_TYPE(x)	(x) |= __DUMMY_TYPE
 #define SET_EXPANDED(x)		(x) |= __EXPANDED
@@ -258,6 +369,7 @@
 #define UNSET_LOADED(x)		(x) &= (__MASK^__LOADED)
 
 /* hex  :: */
+#if 0
 #define IS_SORT_NAME(x)		(((x) & __SORT_MASK) == 0)
 #define IS_SORT_SIZE(x)		(((x) & __SORT_MASK) == __SORT_SIZE)
 #define IS_SORT_TIME(x)		(((x) & __SORT_MASK) == __SORT_TIME)
@@ -279,13 +391,16 @@
 /* hex  | */
 #define IS_DESCENDING(x)	((x) & __SORT_DESC)
 #define IS_ASCENDING(x)		(!((x) & __SORT_DESC))
+#endif
+
 #define IS_BROKEN_LNK(x)	((x) & __BROKEN_LNK)
 #define HAS_HIDDEN(x)		((x) & __HAS_HIDDEN)
 #define SHOWS_HIDDEN(x)		((x) & __SHOW_HIDDEN)
-
+#if 0
 #define SET_DESCENDING(x)	(x) |= __SORT_DESC
 #define TOGGLE_ASCENDING(x)	(x) ^= __SORT_DESC
 #define SET_ASCENDING(x)	(x) &= (__MASK^__SORT_DESC)
+#endif
 #define SET_BROKEN_LNK(x)	(x) |= __BROKEN_LNK
 #define SET_HAS_HIDDEN(x)	(x) |= __HAS_HIDDEN
 #define SET_SHOWS_HIDDEN(x)	(x) |= __SHOW_HIDDEN
@@ -306,9 +421,11 @@
 #define SET_DIR(x)		(x) |= __DIR
 #define SET_EXE(x)		(x) |= __EXE
 #define SET_NOWRITE(x)		(x) |= __NOWRITE
+#define UNSET_NOWRITE(x)	(x) &= (__NOWRITE^0xffffffff)
 #define SET_NOACCESS(x)		(x) |= __NOACCESS
 
 /* hex |: */
+#if 0
 #define IS_SIZE_S(x)		(((x) & __SIZE_MASK) == 0)
 #define IS_SIZE_M(x)		(((x) & __SIZE_MASK) == __SIZE_M)
 #define IS_SIZE_L(x)		(((x) & __SIZE_MASK) == __SIZE_L)
@@ -319,17 +436,20 @@
 #define SET_SIZE_M(x)		(x) = (((x)&(__SIZE_MASK^__MASK)) | __SIZE_M)
 #define SET_SIZE_L(x)		(x) = (((x)&(__SIZE_MASK^__MASK)) | __SIZE_L)
 #define SET_SIZE_XL(x)		(x) = (((x)&(__SIZE_MASK^__MASK)) | __SIZE_XL)
+#endif
 
 #define IS_INCOMPLETE(x)	((x) & __INCOMPLETE)
 #define SET_INCOMPLETE(x)	(x) |= __INCOMPLETE
 #define UNSET_INCOMPLETE(x)	(x) &= (__INCOMPLETE^0xffffffff)
 #define TOGGLE_INCOMPLETE(x)	(x) ^= __INCOMPLETE
 
+#if 0
 #define IS_CUSTOM_ICON(x)	((x) & __CUSTOM_ICON) /* subtype use APP type */
 #define SET_CUSTOM_ICON(x)	(x) |= __CUSTOM_ICON /* subtype use APP type */
+#endif
 
-#define IS_IN_TERM(x)		((x) & __IN_TERM) /* subtype use APP type */
-#define SET_IN_TERM(x)		(x) |= __IN_TERM /* subtype use APP type */
+#define IS_IN_TERM(x)		((x) & __IN_TERM) /* subtype  */
+#define SET_IN_TERM(x)		(x) |= __IN_TERM /* subtype  */
 
 #define IS_MOUNTED(x)		((x) & __MOUNTED) 
 #define SET_MOUNTED(x)		(x) |= __MOUNTED 
@@ -339,6 +459,11 @@
 #define IS_CUT(x)		((x) & __CUT)
 #define SET_CUT(x)		(x) |= __CUT
 #define UNSET_CUT(x)		(x) &= (__CUT^0xffffffff)
+
+/*#define IS_SHADED(x)		((x) & __SHADED)
+#define SET_SHADED(x)		(x) |= __SHADED
+#define UNSET_SHADED(x)		(x) &= (__SHADED^0xffffffff)*/
+
 #define IS_ERASED_SPACE(x)	((x) & __ERASED_SPACE)
 #define SET_ERASED_SPACE(x)	(x) |= __ERASED_SPACE
 #define UNSET_ERASED_SPACE(x)	(x) &= (__ERASED_SPACE^0xffffffff)
@@ -348,54 +473,118 @@
 
 
 /****  preferences flag (view and preferences) *****/
+#define INDIVIDUAL_TOGGLE	0x80000000
+
 /* views: */
+/*#define ACTIVATE_ALL		(ACTIVATE_BOOK|ACTIVATE_LOCAL|ACTIVATE_SMB|ACTIVATE_TRASH|ACTIVATE_FIND)*/
+#define ACTIVATE_BOOK		0X01
+#define ACTIVATE_LOCAL		0X02
+#define ACTIVATE_SMB		0X04
+/*#define ACTIVATE_RECENT		0X08*/
+#define ACTIVATE_TRASH		0X10
+/*#define ACTIVATE_FSTAB		0X20*/
+#define ACTIVATE_FIND		0X40
 
-#define SHOW_SIZE	0x01
-#define SHOW_DATE	0x02
-#define SHOW_GID	0x04
-#define SHOW_UID	0x08
-#define SHOW_MODE	0x10
+#define SHOW_COLUMNS		(SHOW_SIZE|SHOW_DATE|SHOW_GID|SHOW_UID|SHOW_MODE)
+#define SHOW_SIZE		0x100
+#define SHOW_DATE		0x200
+#define SHOW_GID		0x400
+#define SHOW_UID		0x800
+#define SHOW_MODE		0x1000
 
-#define SHOW_MM		0x20
-#define SHOW_TB1	0x40
-#define SHOW_TB2	0x80
-#define SHOW_F		0x100
-#define SHOW_TITLES	0x200
+#define DEFAULT_VIEW 		0x2000
+#define SMALL_VIEW 		0x4000
+#define DETAILED_VIEW 		0x8000
+#define ICON_VIEW 		0x10000
 
-#define QUICK_HIDE_MASK	(SHOW_TITLES|SHOW_MM|SHOW_TB1|SHOW_TB2|SHOW_F)
+#define SORT_ASCENDING		0x20000
+/*#define 			0x40000*/
+/*#define 			0x80000 */
 
-/*#define HIDE_LOCAL	0x400
-#define HIDE_NETWORK	0x800*/
+/*#define 			0x100000*/
+/*#define 			0x200000*/
+/*#define 			0x400000*/
+/*#define 			0x800000*/
 
-#define ICON_VIEW 	0x1000
-#define DEFAULT_VIEW 	0x2000
-#define SMALL_VIEW 	0x4000
-#define DETAILED_VIEW 	0x8000
+/*#define 			0x1000000*/
+/*#define 			0x2000000*/
+/*#define 			0x4000000*/
+/*#define 			0x8000000*/
 
-#define HIDE_WASTE_B	0x10000
-#define VIEW_MASK	0x1ffff
+/*#define 			0x10000000*/
+/*#define 			0x20000000*/
+/*#define 			0x40000000*/
+/* above: INDIVIDUAL_TOGGLE	0x80000000 */
 
-/* preferences: */
+/*#define VIEW_MASK	0x1ffff*/
 
-#define PREFERENCE_MASK	0xfff00000
+/* global preferences: */
 
-#define DRAG_DO_COPY	0x100000
-#define ENABLE_GTK_CLICK	0x200000
-#define RSH_X_SSH	0x400000
-#define RSYNC_X_SCP	0x800000
-
-#define SHOW_DOT 	0x1000000
-#define IMAGE_PREVIEW	0x2000000
-#define ENABLE_AUTO_T	0x4000000
-#define ENABLE_MONITOR  0x8000000
-
-#define FILETYPE_SUBS	0x10000000
-#define CUSTOM_HOME	0x20000000
-#define AUTOSCROLL	0x40000000
-#define ENABLE_RESIZE_FONTS	0x80000000
+/*#define PREFERENCE_MASK		(0xffffffff ^ VIEW_MASK)*/
 
 
+#define DEFAULT_PREFERENCES    (SHOW_TB1 |  SHOW_TITLES | IMAGE_PREVIEW |  TEXT_HEADERS);
+
+#define QUICK_HIDE_MASK	(SHOW_TITLES|SHOW_TB1|SHOW_TB2|SHOW_F)
+/*#define HIDE_WASTE_B		0x01*/
+/*#define SHOW_MM			0x02*/
+#define SHOW_TB1		0x04
+#define SHOW_TB2		0x08
+
+#define SHOW_F			0x10
+#define SHOW_TITLES		0x20
+/*#define DISABLE_TEXT_COLOR	0x40*/
+/*#define DISABLE_EASY_EDIT	0x80*/
+
+/*#define DRAG_DO_COPY		0x100*/
+/*#define ENABLE_GTK_CLICK	0x200*/
+/*#define RSH_X_SSH		0x400*/
+/*#define RSYNC_X_SCP		0x800*/
+
+#define SHOW_DOT 		0x1000
+#define IMAGE_PREVIEW		0x2000
+/*#define ENABLE_AUTO_T		0x4000*/
+/*#define ENABLE_MONITOR  	0x8000*/
+
+
+#define ENABLE_RESIZE_FONTS	0x10000
+/*#define SVG_ICONS		0x20000*/
+/*#define AUTOSCROLL		0x40000*/
+/*#define VERBOSE			0x80000 */
+
+#define TEXT_HEADERS		0x100000
+/*#define 			0x200000*/
+/*#define 			0x400000*/
+/*#define 			0x800000*/
+
+/*#define 			0x1000000*/
+/*#define 			0x2000000*/
+/*#define 			0x4000000*/
+/*#define 			0x8000000*/
+
+/*#define 			0x10000000*/
+/*#define 			0x20000000*/
+/*#define 			0x40000000*/
+/* above: INDIVIDUAL_TOGGLE	0x80000000 */
 
 #define BIT_MASK	0xffffffff
 
+#define GLADE_HOOKUP_OBJECT(component,widget,name) \
+  g_object_set_data_full (G_OBJECT (component), name, \
+    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)
+
+#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
+  g_object_set_data (G_OBJECT (component), name, widget)
+
+    
+#ifdef TRACE    
+#define WIDGET_P_CHECK  if (widgets_p == NULL) g_assert_not_reached();
+#else
+#ifdef DEBUG
+#define WIDGET_P_CHECK  if (widgets_p == NULL) g_warning("CRITICAL: widgets_p == NULL");
+#else
+#define WIDGET_P_CHECK
+#endif
+#endif
+    
 #endif /*__CONSTANTS__*/
