@@ -49,71 +49,90 @@
 #ifdef XFCE_DISABLE_DEPRECATED
 #undef XFCE_DISABLE_DEPRECATED
 #endif
-#include <libxfcegui4/dialogs.h>
-#include "glade_support.h"
+#ifdef HAVE_LIBXFCEGUI4
+#include <libxfcegui4/libxfcegui4.h>
+#endif
+
 
 #include "constants.h"
 #include "types.h"
+#include "primary.h"
+#include "secondary.h"
+#include "actions_lib.h"
 
-#include "smb_module.h"
-#include "modules.h"
+#include "tubo.h"
 
-#include "run.h"
-
-#include "terminal.h"
-#include "input.h"
-#include "misc.h"
-#include "entry.h"
-#include "xmcs-manager.h"
+#include "run.i"
 
 
-static 
-void 
-save_to_open_history(		gchar *path2save, 
-				gchar *in_cmd, 
-				int in_term)
-{
-    gchar *xdg_dir=xfce_resource_save_location (XFCE_RESOURCE_CACHE,"/",TRUE);
-    gchar *dbh_file=g_build_filename(xdg_dir,OPEN_FILE,NULL);
-    GString *gs;
-    DBHashTable *d;
-    gchar *data;
-    int length;
-    gchar *basename;
 
-    g_free(xdg_dir);
-    if (!path2save) return;
-    basename=g_path_get_basename(path2save);
-    if ((d=DBH_open(dbh_file))==NULL){
-    	if ((d=DBH_create(dbh_file, 11))==NULL) {
-		unlink(dbh_file);
-		if ((d=DBH_create(dbh_file, 11))==NULL)	return;
-	}
-    }
-    gs = g_string_new(basename);
-    g_free(basename);
-    sprintf((char *)DBH_KEY(d), "%10u", g_string_hash(gs));
-    g_string_free(gs, TRUE);
-    data = (gchar *)DBH_DATA(d);
-    if (in_term) *data = 1;
-    else *data=0;
-    data++;
-    
-    length=strlen(in_cmd)+2;
-    if (length > DBH_MAXIMUM_RECORD_SIZE(d))length = DBH_MAXIMUM_RECORD_SIZE(d);
-    
-    strncpy(data,in_cmd, length-2);
-    DBH_set_recordsize (d,length);
-    
-    DBH_update(d);
-    DBH_close(d);
-    g_free(dbh_file);
+/* terminal stuff */
+
+G_MODULE_EXPORT
+void
+RECENT_add2history(widgets_t *widgets_p, gchar *path){
+    if (!function_rational("plugins","xffm_recent",(void *)path,widgets_p,"add2history"))
+	function_rational("plugins","xffm_frequent",(void *)path,widgets_p,"add2history");
 }
 
+G_MODULE_EXPORT
+const gchar *xffm_what_term(void){
+    static gchar *term=NULL;
+    if (term){
+       g_free(term);
+       term=NULL;
+    }
+    term=NULL;
+    if (getenv("TERMCMD") && strlen( getenv("TERMCMD"))){
+	    if (MIME_is_valid_command(getenv("TERMCMD"))){
+		    term = g_strdup(getenv("TERMCMD"));
+	    } else {
+		    g_warning("TERMCMD=%s: %s",getenv("TERMCMD"),strerror(errno));
+	    }
+    }
+    if (!term) {
+	term=g_strdup("xterm");
+    }
+    if ((strncmp(term,"xterm",strlen("xterm"))==0 || strstr(term,"xfce4-terminal")) 
+         && getenv("XFFM_HOLD_XTERM") && strlen( getenv("XFFM_HOLD_XTERM"))){
+	gchar *p=term;
+	term=g_strconcat(p," -hold",NULL);
+	g_free(p);
+    }
+    return (const gchar *)term;	
+}
+
+/*static void new_terminal_query(void){
+    show_input(NEW_TERM_INPUT,NULL);
+}*/
+
+G_MODULE_EXPORT
+void xffm_new_terminal_path(widgets_t *widgets_p,gchar *workdir){
+    GError *error=NULL;
+    int argc;
+    gchar **argv;
+  
+    g_shell_parse_argv (xffm_what_term(), &argc,&argv,&error);
+    if (error){
+	gchar *msg = g_strcompress (error->message);
+	print_diagnostics(widgets_p,"xfce/error",msg,": ",xffm_what_term(),"\n",NULL);
+	g_error_free(error);
+	g_free (msg);
+	return;
+    }
+    if (!workdir) workdir=(gchar *)g_get_home_dir();
+    xffm_runvwd(widgets_p,workdir,argv);
+    g_strfreev (argv);
+    return;
+}
+
+
+/* end terminal stuff */
+
 G_MODULE_EXPORT
 const 
 gchar *
-get_from_open_history(		gchar *path2find, 
+xffm_get_from_open_history(	gchar *path2find, 
 				int *in_term){
     gchar *xdg_dir=xfce_resource_save_location (XFCE_RESOURCE_CACHE,"/",TRUE);
     gchar *dbh_file=g_build_filename(xdg_dir,OPEN_FILE,NULL);
@@ -159,43 +178,71 @@ get_from_open_history(		gchar *path2find,
 
 G_MODULE_EXPORT
 int 
-runvwd(			const gchar *workdir,
+xffm_runvwd(		widgets_t *widgets_p,
+			const gchar *workdir,
 			char *argv[])
 {
 
     int i;
     GError *error=NULL;
     
+    TRACE("xffm_runvwd now, widgets_p=0x%x",(unsigned)widgets_p);
+#ifdef TRACE
+    {
+	gchar **p;
+	for (p=argv; *p; p++){
+	    TRACE("arg[]=%s",*p);
+	}
+    }
+#endif
+    
     if (!argv || !argv[0]) {
 	g_warning("!argv || !argv[0]");
 	return FALSE;
     }
     if (!workdir || !g_file_test(workdir,G_FILE_TEST_IS_DIR)) {
-	workdir=get_selected_chdir();
-	if (!g_file_test(workdir,G_FILE_TEST_IS_DIR)) workdir=GETWD;
+	/*g_warning("xffm_runvwd(): workdir==NULL");*/
+	workdir=g_get_home_dir();
     }
     
 
-    if (strcmp(workdir,GETWD)!=0) {
-	print_diagnostics(NULL,"$chdir ",workdir,"\n$",argv[0],NULL);
-	xffm_setenv("PWD",(gchar *)workdir,FALSE);
-#ifdef DEBUG
-	printf("DBG: getenv(PWD)=%s\n",getenv("PWD"));
-#endif
+    xffm_setenv("PWD",(gchar *)workdir,FALSE);
+    chdir(workdir);
+    TRACE("TRACE: getenv(PWD)=%s\n",getenv("PWD"));
+    
+    print_diagnostics(widgets_p,NULL,"$chdir ",workdir,"\n$",argv[0],NULL);
+    print_diagnostics(widgets_p,NULL,"$",argv[0],NULL);
+    for (i=1;argv[i];i++) {
+	print_diagnostics(widgets_p,NULL," ",argv[i],NULL);
     }
-    else {
-	print_diagnostics(NULL,"$",argv[0],NULL);
-    }
-    for (i=1;argv[i];i++) print_diagnostics(NULL," ",argv[i],NULL);
-    print_diagnostics(NULL,"\n",NULL);
-    print_status("xfce/info",_("Executing")," ",argv[0],NULL);
+    print_diagnostics(widgets_p,NULL,"\n",NULL);
 
-    if (strcmp(argv[0],"sudo")==0) print_status("xfce/sudo", _("Executing"), " sudo ", argv[1], NULL);
-    else print_status("xfce/info", _("Executing"), " ", argv[0], NULL);
+    if (strcmp(argv[0],"sudo")==0)
+    {
+	gchar *f=g_strdup_printf("sudo %s",argv[1]);
+	gchar *g=g_strdup_printf(_("Executing %s"),f);
+	print_status(widgets_p,"xfce/info", g, NULL);
+	g_free(g);
+	g_free(f);
+    }
+    else 
+    {
+	gchar *g;
+	if (g_file_test(argv[0],G_FILE_TEST_EXISTS)) {
+	    gchar *f;
+	    f=g_path_get_basename(argv[0]);
+	    g=g_strdup_printf(_("Executing %s"),f);
+	    g_free(f);
+	} else {
+	    g=g_strdup_printf(_("Executing %s"),argv[0]);
+	}
+	print_status(widgets_p,"xfce/info", g, NULL);
+	g_free(g);
+    }
 
     if (!g_spawn_async(workdir,argv,NULL,G_SPAWN_SEARCH_PATH,NULL,NULL,NULL,&error)){
 	  gchar *msg = g_strcompress (error->message);
-	  print_diagnostics("xfce/error",msg,":\n",argv[0] ,"\n",NULL);
+	  print_diagnostics(widgets_p,"xfce/error",msg,":\n",argv[0] ,"\n",NULL);
 	  g_error_free (error);
 	  g_free (msg);
 	  chdir (GETWD);
@@ -203,10 +250,9 @@ runvwd(			const gchar *workdir,
 	  return FALSE;
     }
 
-    if (strcmp(workdir,GETWD)!=0) print_diagnostics(NULL,"$chdir ",GETWD,"\n",NULL);
+    /*print_diagnostics(widgets_p,NULL,"$chdir ",GETWD,"\n",NULL);*/
     
     xffm_setenv("PWD",(gchar *)GETWD,FALSE);
-
     chdir(GETWD);
     return TRUE;
 
@@ -215,7 +261,7 @@ runvwd(			const gchar *workdir,
 
 G_MODULE_EXPORT
 void 
-save_flags(		gchar *in_cmd, 
+xffm_save_flags(	gchar *in_cmd, 
 			gboolean interm, 
 			gboolean hold)
 {
@@ -237,7 +283,7 @@ save_flags(		gchar *in_cmd,
     gs = g_string_new(in_cmd);
     sprintf((char *)DBH_KEY(runflags), "%10u", g_string_hash(gs));
     g_string_free(gs, TRUE);
-    /*printf("DBG: bookmarking with key=%s\n",d_path);*/
+    /*printf("TRACE: bookmarking with key=%s\n",d_path);*/
     flags = (int *)runflags->data;
     flags[0]=interm;
     flags[1]=hold;
@@ -245,12 +291,12 @@ save_flags(		gchar *in_cmd,
     
     DBH_update(runflags);
     DBH_close(runflags);
-    D(printf("flags saved in dbh file for %s\n",in_cmd);)
+    TRACE("flags saved in dbh file for %s\n",in_cmd);
 }
 
 G_MODULE_EXPORT
 void
-recover_flags(		gchar *in_cmd,
+xffm_recover_flags(	gchar *in_cmd,
 			gboolean *interm,
 			gboolean *hold)
 {
@@ -264,7 +310,7 @@ recover_flags(		gchar *in_cmd,
     
     if((runflags = DBH_open(g)) == NULL)
     {
-	    D(g_warning("Cannot open %s\n",g);)
+	    TRACE("Cannot open %s\n",g);
 	    *interm=0;
 	    *hold=0;
 	    return;
@@ -272,59 +318,22 @@ recover_flags(		gchar *in_cmd,
     gs = g_string_new(in_cmd);
     sprintf((char *)DBH_KEY(runflags), "%10u", g_string_hash(gs));
     g_string_free(gs, TRUE);
-    /*printf("DBG: bookmarking with key=%s\n",d_path);*/
+    /*printf("TRACE: bookmarking with key=%s\n",d_path);*/
     flags = (int *)runflags->data;
     DBH_load(runflags);
     *interm = flags[0];
     *hold = flags[1];
     DBH_close(runflags);
 
-    D(printf("flags recovered from dbh file for %s, interm=%d hold=%d\n",in_cmd,*interm,*hold);)
+    TRACE("flags recovered from dbh file for %s, interm=%d hold=%d\n",in_cmd,*interm,*hold);
 }
 
-/* this function is taken and modified from libxfce4gui (see credits in dialogs.c): */
-static 
-gboolean
-xfce_confirm_custom (		const gchar *text,
-				const gchar *action_false,
-				const gchar *action_true)
-{
-    GtkWidget *dialog, *button;
-    int response = GTK_RESPONSE_NONE;
-
-    if (!action_false || !action_true) {
-	g_error("!action_false || !action_true");
-    }
-
-    dialog = gtk_message_dialog_new (NULL,
-				     GTK_DIALOG_MODAL,
-				     GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
-				     text);
-
-    button = mixed_button_new ("gtk-no",action_false);    
-    gtk_widget_show (button);
-    gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_NO);
-
-    button = mixed_button_new ("gtk-yes",action_true);
-    gtk_widget_show (button);
-    gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_YES);
-
-    /*gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);*/
-    gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
-
-    response = gtk_dialog_run (GTK_DIALOG (dialog));
-    gtk_widget_hide (dialog);
-    gtk_widget_destroy (dialog);
-
-    if (response == GTK_RESPONSE_YES) return TRUE;
-    else return FALSE;
-}
-
-
+/* use absolute path to call this function...*/
 G_MODULE_EXPORT
 int 
-on_run_path(		char *in_cmd, 
-			char *path, 
+xffm_on_run_path(	widgets_t *widgets_p,
+			char *in_cmd, 
+			const gchar *path, 
 			gboolean interm, 
 			gboolean remember, 
 			gboolean put_in_history,
@@ -332,16 +341,15 @@ on_run_path(		char *in_cmd,
 {
     GError *error=NULL;
     const gchar *command;
-    gchar *name;
+    gchar *name=NULL;
     int argc;
     gchar **argv;
     gchar *wd=NULL;
     if (!g_file_test(in_cmd,G_FILE_TEST_EXISTS) && !MIME_is_valid_command(in_cmd)){
 	if (!g_file_test(in_cmd,G_FILE_TEST_EXISTS))
-	    print_diagnostics("xfce/error",strerror(ENOENT),": ",in_cmd,"\n",NULL);
+	    print_diagnostics(widgets_p,"xfce/error",strerror(ENOENT),": ",in_cmd,"\n",NULL);
 	else
-	    print_diagnostics("xfce/error",strerror(ENOEXEC),": ",in_cmd,"\n",NULL);
-	    
+	    print_diagnostics(widgets_p,"xfce/error",strerror(ENOEXEC),": ",in_cmd,"\n",NULL);
 	return FALSE;
     }
 
@@ -350,64 +358,88 @@ on_run_path(		char *in_cmd,
     /* why did I ever use a relative path here? Reverting cause it breaks
      * doubleclick on .html files...
      * if (path) name=g_path_get_basename(path); else name=g_strdup("");
+     *
+     * The reason why is that applications like abiword break with absolute
+     * paths if the paths contain spaces in them. So again I revert, testing
+     * for doubleclick with .html files...
+     *
+     * if (path) {name=g_strdup(path);} else {name=g_strdup(""); }
      * */
-    if (path) name=g_strdup(path); else name=g_strdup("");
+    if (path && strlen(path)) {
+	gchar *t;
+	/* strip quotes from dirname */
+	if (*path=='\"') wd=g_path_get_dirname(path+1);
+	else wd=g_path_get_dirname(path);
+	
+	/* leave quotes on basename */
+	if (*path=='\"') t=g_path_get_basename(path+1);
+	else t=g_path_get_basename(path);
+	if (strchr(t,'\"')) name=g_strdup_printf("\"%s",t);
+	else name=g_strdup_printf("\"%s\"",t);
+	g_free(t);	    
+    } else name=g_strdup("");
     
     command = MIME_mk_command_line(in_cmd, name, interm, hold);
+    TRACE("command=%s",command);
     if (!command){
-    	if (name) g_free(name);   
+    	g_free(name);   
+	g_free (wd);
 	g_warning("!command from %s",in_cmd);
 	return FALSE;
     }
-    if (name) g_free(name); 
-    name = NULL; 
 
-    if (path) {
-      wd=g_path_get_dirname((const gchar *)path);	    
-    } else if (g_file_test(in_cmd,G_FILE_TEST_EXISTS)){
-      wd=g_path_get_dirname((const gchar *)in_cmd);
-    } 
     
-#ifdef DEBUG
-    printf("in_cmd=%s\n",command);
-#endif
+    TRACE("in_cmd=%s\n",command);
     g_shell_parse_argv (command, &argc,&argv,&error);
     if (error){
 	gchar *msg = g_strcompress (error->message);
-	print_diagnostics("xfce/error",msg,":\n",command,"\n",NULL);
+	TRACE(error->message);
+	print_diagnostics(widgets_p,"xfce/error",msg,":\n",command,"\n",NULL);
 	g_error_free(error);
 	g_free (msg);
 	g_free (wd);
+	g_free(name); 
 	return FALSE;
     }
-    TRACE("going to runvwd");
-    if (runvwd(wd,argv)){
+    TRACE("going to xffm_runvwd %s %s",wd,argv[0]);
+    if (wd) chdir(wd);
+    if (xffm_runvwd(widgets_p,wd,argv)){
 	/* recent history: */
-	if (path) RECENT_add2history(path); 
-	save_to_open_history(path,in_cmd,interm);
+	if (path && strlen(path)){
+	    if (!g_file_test(path,G_FILE_TEST_EXISTS)) g_warning("%s does not exist",path);
+	    else RECENT_add2history(widgets_p,(gchar *)strip_quotes(path));
+	} 
+        TRACE("save_to_open_history=%s->%s(%d)",strip_quotes(name),in_cmd,interm);
+	save_to_open_history((gchar *)strip_quotes(name),in_cmd,interm);
     }
     g_free(wd); 
     g_strfreev (argv);
     
+    TRACE("put_in_history=%d",put_in_history);
+    
     if (put_in_history){
       gchar *xdg_dir=xfce_resource_save_location (XFCE_RESOURCE_CACHE,"/",TRUE);
       gchar *f=g_build_filename(xdg_dir,RUN_DBH_FILE,NULL);
 
       g_free(xdg_dir);
+	TRACE("XFC_save_to_history(%s,%s)",f,in_cmd);
       XFC_save_to_history(f,in_cmd);
-      save_flags(in_cmd,interm,hold);
+      xffm_save_flags(in_cmd,interm,hold);
       g_free(f);
     }
+
+    TRACE("path=%s,remember=%d)",path,remember);
     
-    if(path && remember)
+    if(name && remember)
     {
 #if 10
 	/* multiple dots? */
-	gchar *p=g_path_get_basename(path);
+	gchar *p=g_path_get_basename(name);
 	gchar *foo=NULL;
-	if (p && strchr(p,'.') && strchr(p,'.') != strrchr(p,'.')  && strlen(strrchr(p,'.'))>1){
+	if (p && strchr(p,'.') && strchr(p,'.') != strrchr(p,'.') && strlen(strrchr(p,'.'))>1){
 	    gchar *m=g_strdup_printf(_("Remember %s or %s?"),strchr(p,'.'),strrchr(p,'.'));
-	    if (xfce_confirm_custom ((const gchar *)m,
+	    if (xffm_confirm (widgets_p,
+				     (const gchar *)m,
 				     (const gchar *)strchr(p,'.'),
 				     (const gchar *)strrchr(p,'.'))){
 		foo=g_strdup_printf("%s",strrchr(p,'.')+1);
@@ -416,45 +448,53 @@ on_run_path(		char *in_cmd,
 	    }	
 	} else {
 	    if (p && strchr(p,'.') && strlen(strrchr(p,'.'))>1) foo=g_strdup_printf("%s",strchr(p,'.')+1);
-	    else foo=g_strdup(path);
+	    else foo=g_strdup(name);
 	}
 #endif
-	if(strlen(path))
+	if(strlen(name))
 	{
 	   command = MIME_mk_command_line(in_cmd, NULL, interm, hold);
 	
-#ifdef DEBUG
-	    printf("DBG: adding %s --> %s\n",path,in_cmd); 
-#endif
-	    print_diagnostics("xfce/info",foo,"-->",command,"\n",NULL);
+	    TRACE("TRACE: adding %s --> %s\n",name,in_cmd); 
+	    print_diagnostics(widgets_p,"xfce/info",foo,"-->",command,"\n",NULL);
 	    MIME_add(foo,command);
 	}
 	g_free(p);
 	g_free(foo);
     }
+    g_free(name); 
+    chdir(GETWD);
     return TRUE;
 }
 
+
 G_MODULE_EXPORT
 int 
-on_run(		char *in_cmd, 
-		tree_entry_t * en, 
+xffm_on_run(	widgets_t *widgets_p,
+		char *in_cmd, 
+		record_entry_t * en, 
 		gboolean in_terminal, 
 		gboolean remember, 
 		gboolean put_in_history, 
 		gboolean hold)
 {
-	char *path=NULL;
-#ifdef USE_SMB_BRANCH
+	gchar *path=NULL;
+	int result;
+
 	if (en && IS_NETFILE(en->subtype)){
-	    int tree_id = get_relative_tree_id();
-	    path = (gchar *)XF_SMBget_cache_file(tree_details->treestuff[tree_id].treeview,en);
+	    path = g_strdup(XF_SMBget_cache_file(en,widgets_p));
 	} 
-	else
-#endif
-	    if (en) path=en->path;
-	else path=NULL;
-	return on_run_path(in_cmd, path, in_terminal, remember, put_in_history, hold);
+	else if (en) path=g_strdup(en->path);
+	else path=g_strdup("");
+	
+	/*if (en) {
+	    gchar *dir=g_path_get_dirname(en->path);
+	    path=g_path_get_basename(en->path);
+	    chdir(dir);
+	}*/
+	result = xffm_on_run_path(widgets_p, in_cmd, path, in_terminal, remember, put_in_history, hold);
+	g_free(path);
+	return result;
 }
 
 
@@ -462,11 +502,11 @@ on_run(		char *in_cmd,
 
 G_MODULE_EXPORT
 void 
-set_run_combo(		xfc_combo_info_t *combo_info)
+xffm_set_run_combo(	widgets_t *widgets_p,
+			record_entry_t *en,
+			xfc_combo_info_t *combo_info)
 {
     gchar *xdg_dir=xfce_resource_save_location (XFCE_RESOURCE_CACHE,"/",TRUE);
-    GtkTreeIter iter;
-    tree_entry_t *en;
     gchar *f=g_build_filename(xdg_dir,RUN_DBH_FILE,NULL); 
     gboolean update=FALSE;
     gboolean docheck=TRUE;
@@ -485,7 +525,6 @@ set_run_combo(		xfc_combo_info_t *combo_info)
     
     XFC_read_history(combo_info,f);
 
-    en = get_selected_entry(&iter);
     if (en) {
 	const gchar *p=MIME_command(en->path);
     	if (p) combo_info->list = g_list_prepend(combo_info->list,g_strdup(p) );
@@ -495,12 +534,12 @@ set_run_combo(		xfc_combo_info_t *combo_info)
 
     {
       gboolean interm,hold;
-      GtkEntry * entry = (GtkEntry *) WIDGET("input_entry");
+      GtkEntry * entry = (GtkEntry *) lookup_widget(widgets_p->window,"input_entry");
       gchar *choice = g_strdup((gchar *)gtk_entry_get_text(entry));
-      GtkWidget *check = WIDGET("checkbutton1");
-      recover_flags(choice,&interm, &hold);
+      GtkWidget *check = lookup_widget(widgets_p->window,"checkbutton1");
+      xffm_recover_flags(choice,&interm, &hold);
       gtk_toggle_button_set_active ((GtkToggleButton *)check,interm);
-      check = WIDGET("checkbutton3");
+      check = lookup_widget(widgets_p->window,"checkbutton3");
       gtk_toggle_button_set_active ((GtkToggleButton *)check,hold);
       if(getenv("XFFM_HOLD_XTERM") && strlen( getenv("XFFM_HOLD_XTERM"))) {
          gtk_toggle_button_set_active ((GtkToggleButton *)check,TRUE);
@@ -517,34 +556,10 @@ set_run_combo(		xfc_combo_info_t *combo_info)
     return;
 }
 
-static gchar *script_types[]={
-    "application/x-csh",
-    "application/x-bsh",
-    "application/x-ksh",
-    "application/x-shellscript",
-    "application/x-tsh",
-    "application/x-zsh",
-    "application/x-perl",
-    NULL
-};
-
-static 
-gboolean 
-is_a_script(const gchar *path)
-{ 
-  const gchar *t=MIME_get_type((const gchar *)path, TRUE);
-  if (t) {
-      int i;
-      for (i=0;script_types[i];i++) if (strncmp(script_types[i],t,strlen(script_types[i]))==0){
-	  return TRUE;
-      }
-  }
-  return FALSE;
-}
 
 G_MODULE_EXPORT
 void 
-double_click_run(	tree_entry_t *en)
+xffm_double_click_run(	widgets_t *widgets_p, record_entry_t *en)
 {
     GError *error=NULL;
     char *a=NULL;
@@ -561,7 +576,15 @@ double_click_run(	tree_entry_t *en)
     if (is_a_script(en->path)) interm=TRUE;
     
     if (interm){
-	a = g_strdup_printf("%s -e \"%s\"",what_term(),en->path);
+	const gchar *the_terminal=xffm_what_term();
+	const gchar *exec_flag="-e";
+	if (strstr("gnome-terminal",the_terminal) 	|| 
+		strstr("gnome2-terminal",the_terminal)	||
+		strstr("Terminal",the_terminal)	||
+		strstr("terminal",the_terminal)	||
+		strstr("xterminal",the_terminal) ) exec_flag="-x";
+		
+	a = g_strdup_printf("%s %s \"%s\"",the_terminal, exec_flag,en->path);
     } else {
         a=g_strdup_printf("\"%s\"",en->path);
     }
@@ -569,96 +592,54 @@ double_click_run(	tree_entry_t *en)
     g_shell_parse_argv (a, &argc,&argv,&error);
     if (error){
 	gchar *msg = g_strcompress (error->message);
-	print_diagnostics("xfce/error",msg,":\n",a,"\n",NULL);
+	print_diagnostics(widgets_p,"xfce/error",msg,":\n",a,"\n",NULL);
 	g_error_free(error);
 	g_free(a);
 	g_free (msg);
 	return;
     }
-    runv(argv);
+    xffm_runvwd(widgets_p,NULL,argv);
     g_strfreev (argv); 
     g_free(a);
     return;
 }
 
-
 G_MODULE_EXPORT
-void 
-double_click_open_with(		tree_entry_t *en)
-{
-    /* open with */
-    gchar *name;
-    int argc;
-    gchar **argv;
-    const gchar *command;
-    const gchar *command_fmt;
-    GError *error=NULL;
+gboolean 
+xffm_try_sudo(widgets_t *widgets_p, char *command, char *arg, char *path){
+    int i;
+    gchar *g;
+    g = g_find_program_in_path("sudo");
+    if (g){
+	char *argument[6];
+	static gchar *sudo_prompt=NULL;
+       /* try SUDO if available before barfing...*/
+	if (sudo_prompt) g_free(sudo_prompt);
+	sudo_prompt = g_strconcat("SUDO_PROMPT=","Password:","\n",NULL);
+	putenv(sudo_prompt);
+	argument[0]="sudo";
+	argument[1]="-S";
+	argument[2]=command;
+	argument[3]=arg;
+	argument[4]=path;
+	argument[5]=NULL;
+	    
+	print_diagnostics(widgets_p,"xfce/sudo",NULL);
+	for (i=0; argument[i]; i++) print_diagnostics(widgets_p,NULL," ",argument[i],NULL);
+	print_diagnostics(widgets_p,NULL,"\n",NULL);
+	easy_widgets_p = widgets_p;
+	Tubo(fork_function, 
+			(void *)argument, 
+			easy_finished_function, 
+			&childFD, 
+			easy_stdout, 
+			easy_stderr,0,FALSE);
+	g_free(g);
+	return TRUE;
+    } 
+    print_diagnostics(widgets_p,"xfce/error",strerror(EINVAL),": ",command," ",arg," ",path,"\n",NULL);
     
-    if (!en || !en->path) return;
-    name=g_path_get_basename(en->path);
+    return FALSE;
+}
     
-    
-    command_fmt = MIME_command(name);
-    
-    if(!command_fmt)
-    {
-	show_input(RUN_DOUBLE_CLICK);
-	print_status("xfce/question",name,NULL);
-    } else {
-        gchar *wd=g_path_get_dirname((const gchar *)en->path);	    
-	command =  MIME_mk_command_line(command_fmt,name,FALSE,FALSE);
 
-
-	g_shell_parse_argv (command, &argc,&argv,&error);
-	if (error){
-	    gchar *msg = g_strcompress (error->message);
-	    print_diagnostics("xfce/error",msg,":\n",command,"\n",NULL);
-	    g_error_free(error);
-	    g_free (msg);
-	    g_free(wd);
-	    return;
-	}
-	runvwd(wd,argv);
-	g_free(wd);
-	g_strfreev (argv); 
-    }
-    g_free(name);
-    return;
-}
-
-
-
-/* callbacks */
-G_MODULE_EXPORT
-void tb_run(GtkButton * button, gpointer user_data)
-{
-    show_input(RUN_INPUT);
-}
-
-G_MODULE_EXPORT
-void sb_run(GtkWidget *w){
-    show_input(RUN_INPUT);
-}
-
-G_MODULE_EXPORT
-void on_open_with_activate(GtkMenuItem * menuitem, gpointer user_data)
-{
-    tree_entry_t *en;
-    GtkTreeIter iter;
-    en = get_selected_entry(&iter);
-    if(!en)
-	show_input(RUN_INPUT);
-    else
-    {
-	show_input(RUN_DOUBLE_CLICK);
-	print_status("xfce/question", _("Input requested"), NULL);
-    }
-
-
-}
-
-G_MODULE_EXPORT
-void on_run_activate(GtkMenuItem * menuitem, gpointer user_data)
-{
-    show_input(RUN_INPUT);
-}
