@@ -31,11 +31,14 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
+
+#ifdef HAVE_LIBXFCEGUI4
 #include <libxfcegui4/libxfcegui4.h>
+#endif
+
 #include <libxfce4mcs/mcs-common.h>
 #include <libxfce4mcs/mcs-manager.h>
 #include <xfce-mcs-manager/manager-plugin.h>
-#include <libxfce4util/libxfce4util.h>
 
 #include "constants.h"
 #include "types.h"
@@ -62,7 +65,7 @@ GtkWidget *radio_cancel,*radio_waste,*radio_unlink;
 GtkWidget *hide_book,*hide_local,*hide_network,
     *hide_find,*hide_trash,*hide_fstab,
     *hide_recent,*hide_frequent,
-    *hold_xterm,*diagnostics,*use_sudo;
+    *hold_xterm,*use_sudo;
 
 #if 0
 static GtkWidget **preference_w;
@@ -89,25 +92,33 @@ enum
 
 /*static gboolean is_running = FALSE;*/
 static GtkWidget *dialog = NULL;
-#include "pixmaps/xffm_icon.xpm"
+#include "xffm_icon.xpm"
 
 /********************************************************/
 static McsManager *mcs_manager = NULL;
 
 enum {
-    /* these are set by checkboxes */
-    XFFM_USE_SUDO,
-    XFFM_DEFAULT_UNLINK,
-    XFFM_HOLD_XTERM,
-    XFFM_DIAGNOSTICS_DISABLED,
-    /* these are editable: */
-    TERMCMD,
-    XFFM_HOME,
-    SMB_USER,
-    SMB_CODESET,
-    XFFM_STATUS_LINE_LENGTH,
-    XFFM_MAX_PREVIEW_SIZE,
-    XFFM_OPTIONS
+	XFFM_DEFAULT_UNLINK,		/* 1 */
+	XFFM_HOLD_XTERM,		/* 2 */
+	XFFM_USE_SUDO,			/* 3 */
+	TERMCMD,			/* 4 */
+	DESKTOP_COLOR,			/* 5 */
+	DESKTOP_BACKGROUND_IMAGE,	/* 6 */
+	USE_DESKTOP_MENU,		/* 7 */
+	USE_DESKTOP_MENU_ICONS,		/* 8 */
+	DISABLE_DESKTOP,		/* 9 */
+	SMB_USER,			/* 10*/
+	XFFM_SINGLE_CLICK_NAVIGATION,	/* 11*/
+	XFFM_DRAG_DOES_COPY,		/* 12*/
+	XFFM_FORCE_DIAGNOSTICS,		/* 13*/
+	XFFM_DISABLE_DIAGNOSTICS,	/* 14*/
+	XFFM_DISABLE_MONITOR,		/* 15*/
+	XFFM_DISABLE_TEXTCOLORS,	/* 16*/
+	XFFM_DISABLE_CELL_EDIT,		/* 17*/
+	XFFM_DISABLE_TIPS,		/* 18*/
+	
+	XFFM_MAX_PREVIEW_SIZE,		/* 19*/
+     XFFM_OPTIONS
 };
 
 typedef struct
@@ -118,16 +129,32 @@ typedef struct
 Options;
 
 static Options xffm_options[XFFM_OPTIONS]={
-	{ "XFFM_USE_SUDO",	     NULL },
-	{ "XFFM_DEFAULT_UNLINK",     NULL },
-	{ "XFFM_HOLD_XTERM",         NULL },
-	{ "XFFM_DIAGNOSTICS_DISABLED",                 NULL },
-	{ "TERMCMD",                 NULL },
-	{ "XFFM_HOME",               NULL },
-	{ "SMB_USER",                NULL },
-	{ "SMB_CODESET",             NULL },
-	{ "XFFM_STATUS_LINE_LENGTH", NULL }, /* FIXME: should be set by spinbutton */
-	{ "XFFM_MAX_PREVIEW_SIZE",   NULL }, /* FIXME: should be set by spinbutton */
+    /* radio button */
+	{ "XFFM_DEFAULT_UNLINK",     	NULL },/*1*/
+    /* check buttons */	
+	{ "XFFM_HOLD_XTERM",         	NULL },/*2*/
+	{ "XFFM_USE_SUDO",	     	NULL },/*3*/
+    /* envars */
+	{ "TERMCMD",                 	NULL },/*4 */
+	{ "DESKTOP_COLOR",             	NULL },/*5 */
+	{ "DESKTOP_BACKGROUND_IMAGE",  	NULL },/*6 */
+	{ "USE_DESKTOP_MENU",          	NULL },/*7 */
+	{ "USE_DESKTOP_MENU_ICONS",    	NULL },/*8 */
+	{ "DISABLE_DESKTOP",    	NULL },/*9 */
+	{ "SMB_USER",                	NULL },/*10*/
+    /* these should be checkbuttons too */
+	{ "XFFM_SINGLE_CLICK_NAVIGATION",NULL },/*11*/
+	{ "XFFM_DRAG_DOES_COPY",	NULL },/*12*/
+    /* these two should be grouped as a radio */
+	{ "XFFM_FORCE_DIAGNOSTICS",	NULL },/*13*/
+	{ "XFFM_DISABLE_DIAGNOSTICS",	NULL },/*14*/
+    /* more check button */
+	{ "XFFM_DISABLE_MONITOR",	NULL },/*15*/
+	{ "XFFM_DISABLE_TEXTCOLORS",	NULL },/*16*/
+	{ "XFFM_DISABLE_CELL_EDIT",	NULL },/*17*/
+	{ "XFFM_DISABLE_TIPS",       	NULL },/*18*/
+    /* this one should be a spinbutton */
+	{ "XFFM_MAX_PREVIEW_SIZE",   	NULL },/*19*/ 
 };
 
 /* Fwd. decl. */
@@ -379,11 +406,7 @@ static void run_xffm_settings_dialog(McsPlugin *mp)
     
     /* pretty header */
     vbox = GTK_DIALOG(dialog)->vbox;
-#ifndef XFCE4_O_X_LIBRARIES
     header = xfce_create_header(mp->icon, _("Xffm Settings"));
-#else
-    header = create_header(mp->icon, _("Xffm Settings"));
-#endif
     gtk_box_pack_start(GTK_BOX(vbox), header, FALSE, TRUE, 0);
     
     add_spacer(GTK_BOX(vbox));
@@ -438,10 +461,8 @@ static void run_xffm_settings_dialog(McsPlugin *mp)
     gtk_widget_show (vbox);
     xfce_framebox_add (XFCE_FRAMEBOX (frame), vbox);
     
-    diagnostics = gtk_check_button_new_with_label (_("Disable diagnostics"));
     hold_xterm = gtk_check_button_new_with_label (_("Hold xterms"));
     use_sudo = gtk_check_button_new_with_label (_("Mount with sudo"));
-    gtk_box_pack_start ((GtkBox *)vbox,diagnostics,FALSE,FALSE,0);
     gtk_box_pack_start ((GtkBox *)vbox,hold_xterm,FALSE,FALSE,0);
     gtk_box_pack_start ((GtkBox *)vbox,use_sudo,FALSE,FALSE,0);
 
@@ -452,7 +473,7 @@ static void run_xffm_settings_dialog(McsPlugin *mp)
     g_signal_connect(radio_unlink, "toggled", G_CALLBACK(remove_toggled), NULL);
 
 
-    g_signal_connect(diagnostics, "toggled", G_CALLBACK(option_toggled), (gpointer)((long)(XFFM_DIAGNOSTICS_DISABLED)));
+    /*g_signal_connect(diagnostics, "toggled", G_CALLBACK(option_toggled), (gpointer)((long)(XFFM_DIAGNOSTICS_DISABLED)));*/
     g_signal_connect(hold_xterm, "toggled", G_CALLBACK(option_toggled), (gpointer)((long)(XFFM_HOLD_XTERM)));
     g_signal_connect(use_sudo, "toggled", G_CALLBACK(option_toggled), (gpointer)((long)(XFFM_USE_SUDO)));
 
@@ -486,8 +507,8 @@ static void run_xffm_settings_dialog(McsPlugin *mp)
     gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
 					 GTK_SHADOW_ETCHED_IN);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
-				    GTK_POLICY_NEVER,
-				    GTK_POLICY_NEVER);
+				    GTK_POLICY_AUTOMATIC,
+				    GTK_POLICY_AUTOMATIC);
     gtk_widget_show(sw);
     xfce_framebox_add (XFCE_FRAMEBOX (frame), sw);
 
@@ -537,7 +558,7 @@ static void run_xffm_settings_dialog(McsPlugin *mp)
 					         "editable", COLUMN_EDITABLE,
 					         NULL);
 
-    gtk_widget_set_size_request(treeview, 350, -1);
+    gtk_widget_set_size_request(treeview, 350, 200);
     gtk_widget_show(treeview);
     gtk_container_add (GTK_CONTAINER (sw), treeview);
 
@@ -545,3 +566,4 @@ static void run_xffm_settings_dialog(McsPlugin *mp)
     gtk_widget_show(dialog);
 }
 
+
